@@ -302,8 +302,8 @@ tracker_ontology_model_new (GFile   *ontology_location,
 			    GError **error)
 {
 	TrackerOntologyModel *model;
-	TrackerSparqlConnection *ontology_conn, *desc_conn;
-	GFileEnumerator *enumerator;
+	TrackerSparqlConnection *ontology_conn, *desc_conn = NULL;
+	GFileEnumerator *enumerator = NULL;
 	GFileInfo *info;
 	GFile *dsc_ontology;
 
