@@ -22,19 +22,6 @@
 
 G_BEGIN_DECLS
 
-typedef enum {
-	TRACKER_VERBOSITY_ERRORS,
-	TRACKER_VERBOSITY_MINIMAL,
-	TRACKER_VERBOSITY_DETAILED,
-	TRACKER_VERBOSITY_DEBUG,
-} TrackerVerbosity;
-
-typedef enum {
-	TRACKER_SCHED_IDLE_ALWAYS,
-	TRACKER_SCHED_IDLE_FIRST_INDEX,
-	TRACKER_SCHED_IDLE_NEVER,
-} TrackerSchedIdle;
-
 typedef enum {
 	TRACKER_SERIALIZATION_FORMAT_SPARQL,
 	TRACKER_SERIALIZATION_FORMAT_TURTLE,
