@@ -82,9 +82,6 @@ gboolean            tracker_db_interface_sqlite_fts_delete_text        (TrackerD
                                                                         int                       rowid,
                                                                         const gchar             **properties,
                                                                         const gchar             **old_text);
-gboolean            tracker_db_interface_sqlite_fts_delete_id          (TrackerDBInterface       *interface,
-                                                                        const gchar              *database,
-                                                                        int                       rowid);
 gboolean            tracker_db_interface_sqlite_fts_rebuild_tokens     (TrackerDBInterface       *interface,
                                                                         const gchar              *database,
                                                                         GError                  **error);
