@@ -65,10 +65,11 @@ get_fts_properties (GHashTable  *tables)
 }
 
 gboolean
-tracker_fts_init_db (sqlite3               *db,
-                     TrackerDBInterface    *interface,
-                     TrackerDBManagerFlags  flags,
-                     GHashTable            *tables)
+tracker_fts_init_db (sqlite3                *db,
+                     TrackerDBInterface     *interface,
+                     TrackerDBManagerFlags   flags,
+                     GHashTable             *tables,
+                     GError                **error)
 {
 	gchar **property_names;
 	gboolean retval;
@@ -76,24 +77,28 @@ tracker_fts_init_db (sqlite3               *db,
 	gchar *err;
 
 	if (sqlite3_load_extension (db, NULL, "sqlite3_fts5_init", &err) != SQLITE_OK) {
-		g_warning ("Could not load fts5 module: %s", err);
+		g_set_error (error,
+		             TRACKER_DB_INTERFACE_ERROR,
+		             TRACKER_DB_OPEN_ERROR,
+		             "Could not load fts5 module: %s", err);
 		return FALSE;
 	}
 #endif
 
 	property_names = get_fts_properties (tables);
-	retval = tracker_tokenizer_initialize (db, interface, flags, (const gchar **) property_names);
+	retval = tracker_tokenizer_initialize (db, interface, flags, (const gchar **) property_names, error);
 	g_strfreev (property_names);
 
 	return retval;
 }
 
 gboolean
-tracker_fts_create_table (sqlite3     *db,
-                          const gchar *database,
-                          gchar       *table_name,
-                          GHashTable  *tables,
-                          GHashTable  *grouped_columns)
+tracker_fts_create_table (sqlite3      *db,
+                          const gchar  *database,
+                          gchar        *table_name,
+                          GHashTable   *tables,
+                          GHashTable   *grouped_columns,
+                          GError      **error)
 {
 	GString *str, *from, *fts;
 	gchar *index_table;
@@ -153,17 +158,14 @@ tracker_fts_create_table (sqlite3     *db,
 	rc = sqlite3_exec(db, str->str, NULL, NULL, NULL);
 	g_string_free (str, TRUE);
 
-	if (rc != SQLITE_OK) {
-		g_assert_not_reached();
-		return FALSE;
-	}
+	if (rc != SQLITE_OK)
+		goto error;
 
 	g_string_append (fts, "tokenize=TrackerTokenizer)");
 	rc = sqlite3_exec(db, fts->str, NULL, NULL, NULL);
-	g_string_free (fts, TRUE);
 
 	if (rc != SQLITE_OK)
-		return FALSE;
+		goto error;
 
 	str = g_string_new (NULL);
 	g_string_append_printf (str,
@@ -172,13 +174,25 @@ tracker_fts_create_table (sqlite3     *db,
 	rc = sqlite3_exec (db, str->str, NULL, NULL, NULL);
 	g_string_free (str, TRUE);
 
-	return (rc == SQLITE_OK);
+error:
+	g_string_free (fts, TRUE);
+
+	if (rc != SQLITE_OK) {
+		g_set_error (error,
+		             TRACKER_DB_INTERFACE_ERROR,
+		             TRACKER_DB_OPEN_ERROR,
+		             "%s", sqlite3_errstr (rc));
+		return FALSE;
+	}
+
+	return TRUE;
 }
 
 gboolean
-tracker_fts_delete_table (sqlite3     *db,
-			  const gchar *database,
-                          gchar       *table_name)
+tracker_fts_delete_table (sqlite3      *db,
+                          const gchar  *database,
+                          gchar        *table_name,
+                          GError      **error)
 {
 	gchar *query;
 	int rc;
@@ -194,15 +208,24 @@ tracker_fts_delete_table (sqlite3     *db,
 		g_free (query);
 	}
 
-	return rc == SQLITE_OK;
+	if (rc != SQLITE_OK) {
+		g_set_error (error,
+		             TRACKER_DB_INTERFACE_ERROR,
+		             TRACKER_DB_OPEN_ERROR,
+		             "%s", sqlite3_errstr (rc));
+		return FALSE;
+	}
+
+	return TRUE;
 }
 
 gboolean
-tracker_fts_alter_table (sqlite3     *db,
-			 const gchar *database,
-			 gchar       *table_name,
-			 GHashTable  *tables,
-			 GHashTable  *grouped_columns)
+tracker_fts_alter_table (sqlite3      *db,
+                         const gchar  *database,
+                         gchar        *table_name,
+                         GHashTable   *tables,
+                         GHashTable   *grouped_columns,
+                         GError      **error)
 {
 	gchar *query, *tmp_name;
 	int rc;
@@ -212,7 +235,7 @@ tracker_fts_alter_table (sqlite3     *db,
 
 	tmp_name = g_strdup_printf ("%s_TMP", table_name);
 
-	if (!tracker_fts_create_table (db, database, tmp_name, tables, grouped_columns)) {
+	if (!tracker_fts_create_table (db, database, tmp_name, tables, grouped_columns, error)) {
 		g_free (tmp_name);
 		return FALSE;
 	}
@@ -222,34 +245,41 @@ tracker_fts_alter_table (sqlite3     *db,
 	rc = sqlite3_exec (db, query, NULL, NULL, NULL);
 	g_free (query);
 
-	if (rc != SQLITE_OK) {
-		g_free (tmp_name);
-		return FALSE;
-	}
+	if (rc != SQLITE_OK)
+		goto error;
 
 	query = g_strdup_printf ("INSERT INTO \"%s\".%s(%s) VALUES('rebuild')",
 				 database, tmp_name, tmp_name);
 	rc = sqlite3_exec (db, query, NULL, NULL, NULL);
 	g_free (query);
 
-	if (rc != SQLITE_OK) {
-		g_free (tmp_name);
-		return FALSE;
-	}
+	if (rc != SQLITE_OK)
+		goto error;
 
 	query = g_strdup_printf ("ALTER TABLE \"%s\".%s RENAME TO %s",
 				 database, tmp_name, table_name);
 	rc = sqlite3_exec (db, query, NULL, NULL, NULL);
 	g_free (query);
+
+error:
 	g_free (tmp_name);
 
-	return rc == SQLITE_OK;
+	if (rc != SQLITE_OK) {
+		g_set_error (error,
+		             TRACKER_DB_INTERFACE_ERROR,
+		             TRACKER_DB_OPEN_ERROR,
+		             "%s", sqlite3_errstr (rc));
+		return FALSE;
+	}
+
+	return TRUE;
 }
 
-void
-tracker_fts_rebuild_tokens (sqlite3     *db,
-			    const gchar *database,
-                            const gchar *table_name)
+gboolean
+tracker_fts_rebuild_tokens (sqlite3      *db,
+			    const gchar  *database,
+                            const gchar  *table_name,
+                            GError      **error)
 {
 	gchar *query;
 	gint rc;
@@ -260,5 +290,13 @@ tracker_fts_rebuild_tokens (sqlite3     *db,
 	rc = sqlite3_exec(db, query, NULL, NULL, NULL);
 	g_free (query);
 
-	g_warn_if_fail (rc == SQLITE_OK);
+	if (rc != SQLITE_OK) {
+		g_set_error (error,
+		             TRACKER_DB_INTERFACE_ERROR,
+		             TRACKER_DB_OPEN_ERROR,
+		             "%s", sqlite3_errstr (rc));
+		return FALSE;
+	}
+
+	return TRUE;
 }
