@@ -26,6 +26,7 @@
 
 #include "tracker-namespace-manager.h"
 #include "tracker-ontologies.h"
+#include "tracker-private.h"
 
 #define MAX_PREFIX_LENGTH 100
 
@@ -36,6 +37,7 @@ struct _TrackerNamespaceManager {
 typedef struct {
 	GHashTable *prefix_to_namespace;
 	GHashTable *namespace_to_prefix;
+	gboolean sealed;
 } TrackerNamespaceManagerPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (TrackerNamespaceManager, tracker_namespace_manager, G_TYPE_OBJECT)
@@ -119,6 +121,8 @@ tracker_namespace_manager_new ()
  * ontologies, if they have been modified since they were installed.
  *
  * Returns: (transfer none): a global, shared #TrackerNamespaceManager instance
+ *
+ * Deprecated: 3.3: Use tracker_sparql_connection_get_namespace_manager() instead.
  */
 TrackerNamespaceManager *
 tracker_namespace_manager_get_default ()
@@ -206,6 +210,10 @@ tracker_namespace_manager_lookup_prefix (TrackerNamespaceManager *self,
  *
  * Only one prefix is allowed for a given namespace, and all prefixes must
  * be unique.
+ *
+ * Since 3.3, This function may not be used on #TrackerNamespaceManager
+ * instances that were obtained through
+ * tracker_sparql_connection_get_namespace_manager().
  */
 void
 tracker_namespace_manager_add_prefix (TrackerNamespaceManager *self,
@@ -220,6 +228,7 @@ tracker_namespace_manager_add_prefix (TrackerNamespaceManager *self,
 	g_return_if_fail (ns != NULL);
 
 	priv = GET_PRIVATE (TRACKER_NAMESPACE_MANAGER (self));
+	g_return_if_fail (priv->sealed == FALSE);
 
 	if (strlen (prefix) > MAX_PREFIX_LENGTH) {
 		g_error ("Prefix is too long: max %i characters.", MAX_PREFIX_LENGTH);
@@ -286,6 +295,44 @@ tracker_namespace_manager_expand_uri (TrackerNamespaceManager *self,
 	}
 }
 
+/**
+ * tracker_namespace_manager_compress_uri:
+ * @self: a #TrackerNamespaceManager
+ * @uri: a URI or compact URI
+ *
+ * If @uri begins with one of the namespaces known to this
+ * #TrackerNamespaceManager, then the return value will be the
+ * compressed URI. Otherwise, %NULL will be returned.
+ *
+ * Returns: (transfer full): (nullable): the compressed URI
+ *
+ * Since: 3.3
+ **/
+char *
+tracker_namespace_manager_compress_uri (TrackerNamespaceManager *self,
+                                        const char              *uri)
+{
+	TrackerNamespaceManagerPrivate *priv;
+	GHashTableIter iter;
+	const char *prefix, *namespace, *suffix;
+
+	g_return_val_if_fail (TRACKER_IS_NAMESPACE_MANAGER (self), NULL);
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	priv = GET_PRIVATE (self);
+
+	g_hash_table_iter_init (&iter, priv->prefix_to_namespace);
+
+	while (g_hash_table_iter_next (&iter, (gpointer *) &prefix, (gpointer *) &namespace)) {
+		if (g_str_has_prefix (uri, namespace)) {
+			suffix = &uri[strlen(namespace)];
+			return g_strdup_printf ("%s:%s", prefix, suffix);
+		}
+	}
+
+	return NULL;
+}
+
 /**
  * tracker_namespace_manager_print_turtle:
  * @self: a #TrackerNamespaceManager
@@ -334,3 +381,11 @@ tracker_namespace_manager_foreach (TrackerNamespaceManager *self,
 
 	g_hash_table_foreach (priv->prefix_to_namespace, func, user_data);
 }
+
+void
+tracker_namespace_manager_seal (TrackerNamespaceManager *self)
+{
+	TrackerNamespaceManagerPrivate *priv = GET_PRIVATE (self);
+
+	priv->sealed = TRUE;
+}
