@@ -51,6 +51,8 @@ TRACKER_AVAILABLE_IN_ALL
 void tracker_resource_set_string (TrackerResource *self, const char *property_uri, const char *value);
 TRACKER_AVAILABLE_IN_ALL
 void tracker_resource_set_uri (TrackerResource *self, const char *property_uri, const char *value);
+TRACKER_AVAILABLE_IN_3_2
+void tracker_resource_set_datetime (TrackerResource *self, const char *property_uri, GDateTime *value);
 
 TRACKER_AVAILABLE_IN_ALL
 void tracker_resource_add_gvalue (TrackerResource *self, const char *property_uri, const GValue *value);
@@ -70,6 +72,8 @@ TRACKER_AVAILABLE_IN_ALL
 void tracker_resource_add_string (TrackerResource *self, const char *property_uri, const char *value);
 TRACKER_AVAILABLE_IN_ALL
 void tracker_resource_add_uri (TrackerResource *self, const char *property_uri, const char *value);
+TRACKER_AVAILABLE_IN_3_2
+void tracker_resource_add_datetime (TrackerResource *self, const char *property_uri, GDateTime *value);
 
 TRACKER_AVAILABLE_IN_ALL
 GList *tracker_resource_get_values (TrackerResource *self, const char *property_uri);
@@ -88,6 +92,8 @@ TRACKER_AVAILABLE_IN_ALL
 const char *tracker_resource_get_first_string (TrackerResource *self, const char *property_uri);
 TRACKER_AVAILABLE_IN_ALL
 const char *tracker_resource_get_first_uri (TrackerResource *self, const char *property_uri);
+TRACKER_AVAILABLE_IN_3_2
+GDateTime *tracker_resource_get_first_datetime (TrackerResource *self, const char *property_uri);
 
 TRACKER_AVAILABLE_IN_ALL
 const char *tracker_resource_get_identifier (TrackerResource *self);
